==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/et_EE.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Tegevused",
    "No activity yet" : "Tegevusi veel pole.",
    "Load more activities" : "Lae rohkem tegevusi",
    "Copied!" : "Kopeeritud!",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘ + C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl + C.",
    "{name} (invisible)" : "{nimi} (nähtamatu)",
    "{name} (restricted)" : "{nimi} (piiratud)",
    "This stream will show events like additions, changes & shares" : "See voog näitab sündmusi nagu lisamised, muudatused ja jagamised",
    "There are no events for this filter" : "Selle filtri jaoks pole ühtegi sündmust",
    "Today" : "Täna",
    "Yesterday" : "Eile",
    "Personal activity feed for %s" : "Isiklik toimingute voog %s",
    "Your feed URL is invalid" : "Sinu uudisvoo URL on vigane",
    "Your settings have been updated." : "Seaded on uuendatud.",
    "Mail" : "Kirjad",
    "Stream" : "Voog",
    "All activities" : "Kõik tegevused",
    "By others" : "Teiste poolt",
    "By you" : "Sinu poolt",
    "\"remote user\"" : "\"eemal olev kasutaja\"",
    "Hello %s," : "Tere %s,",
    "Activity notification" : "Tegvuste teavitused",
    ", " : ", ",
    "%s and %s" : "%s ja %s",
    "Activity" : "Tegevused",
    "Activity feed" : "Toimingute voog",
    "Notify about your own actions via email" : "Teavite omaenda tegevustest e-postiga",
    "You need to set up your email address before you can receive notification emails." : "Enne teavituskirjade saamist pead sa lisama oma e-posti aadressi.",
    "Send emails:" : "Saada kirjad:",
    "Hourly" : "Iga tund",
    "Daily" : "Iga päev",
    "Weekly" : "Iga nädal",
    "Enable RSS feed" : "Luba RSS voog",
    "No more events to load" : "Pole rohkem sündmusi, mida laadida.",
    "Files" : "Failid"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/et_EE.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Tegevused",
    "An error occurred while loading activities" : "Tegevuse laadimisel tekkis tõrge",
    "No activity yet" : "Tegevusi veel pole.",
    "Load more activities" : "Lae rohkem tegevusi",
    "Copied!" : "Kopeeritud!",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘ + C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl + C.",
    "{name} (invisible)" : "{nimi} (nähtamatu)",
    "{name} (restricted)" : "{nimi} (piiratud)",
    "in {path}" : "{Kataloogis}",
    "This stream will show events like additions, changes & shares" : "See voog näitab sündmusi nagu lisamised, muudatused ja jagamised",
    "There are no events for this filter" : "Selle filtri jaoks pole ühtegi sündmust",
    "Today" : "Täna",
    "Yesterday" : "Eile",
    "Personal activity feed for %s" : "Isiklik toimingute voog %s",
    "Your feed URL is invalid" : "Sinu uudisvoo URL on vigane",
    "Your settings have been updated." : "Seaded on uuendatud.",
    "Settings have been updated." : "Seaded on uuendatud.",
    "Mail" : "Kirjad",
    "Stream" : "Voog",
    "All activities" : "Kõik tegevused",
    "By others" : "Teiste poolt",
    "By you" : "Sinu poolt",
    "\"remote user\"" : "\"eemal olev kasutaja\"",
    "Hello %s" : "Tere 1%s",
    "Hello %s," : "Tere %s,",
    "There was some activity at %s" : "Mõningane tegevus 1%s",
    "Activity notification" : "Tegvuste teavitused",
    ", " : ", ",
    "%s and %s" : "%s ja %s",
    "Activity" : "Tegevused",
    "Activity feed" : "Toimingute voog",
    "Configure the default activity settings for new users." : "Uute kasutajate vaiketegevuste seadete konfigureerimine.",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Valige, milliste tegevuste jaoks soovite saada meilisõnumit ja mis peaks ilmuma aktiivsuse rakenduste voos.",
    "Notify about your own actions via email" : "Teavite omaenda tegevustest e-postiga",
    "You need to set up your email address before you can receive notification emails." : "Enne teavituskirjade saamist pead sa lisama oma e-posti aadressi.",
    "Send emails:" : "Saada kirjad:",
    "Hourly" : "Iga tund",
    "Daily" : "Iga päev",
    "Weekly" : "Iga nädal",
    "Settings" : "Seaded",
    "Enable RSS feed" : "Luba RSS voog",
    "No more events to load" : "Pole rohkem sündmusi, mida laadida.",
    "Files" : "Failid"
},
"nplurals=2; plural=(n != 1);");
